_me = obj_conference_banner.prototype;

function obj_conference_banner() {};

_me.__constructor = async function () {
	if (GWOthers.getItem('BANNER_OPTIONS', 'norecordingbanner') > 0) {
		this._destruct();
		return;
	}
	this._getAnchor('iframe').src = 'https://webdownload.icewarp.com/recording-banner/#type=' + this._css + '&data=' + encodeURIComponent(sPrimaryAccountCONFERENCE_PARAM) + '&lang=' + GWOthers.getItem('LAYOUT_SETTINGS', 'language');
};